@@ -387,7 +387,7 @@ delete bigfder;
 #line 489 "./decision_rule.hweb"
 ;
 /*25:*/
-#line 658 "./decision_rule.hweb"
+#line 652 "./decision_rule.hweb"
 
 bool calcFixPoint(emethod em,Vector&out)
 {
@@ -496,13 +496,7 @@ fnorm= f.getNorm();
 if(fnorm<=flastnorm)
 urelax_found= true;
 else
-#ifndef _MSC_VER
 urelax*= std::min(0.5,flastnorm/fnorm);
-#else
-
-
-urelax*= min(0.5,flastnorm/fnorm);
-#endif
 }
 
 
@@ -540,7 +534,7 @@ int newton_iter_total;
 #line 52 "./decision_rule.hweb"
 ;
 /*26:*/
-#line 699 "./decision_rule.hweb"
+#line 693 "./decision_rule.hweb"
 
 class ExplicitShockRealization;
 class SimResults{
@@ -574,7 +568,7 @@ void writeMat4(FILE*fd,const char*lname)const;
 #line 53 "./decision_rule.hweb"
 ;
 /*27:*/
-#line 731 "./decision_rule.hweb"
+#line 725 "./decision_rule.hweb"
 
 class SimResultsStats:public SimResults{
 protected:
@@ -595,7 +589,7 @@ void calcVcov();
 #line 54 "./decision_rule.hweb"
 ;
 /*28:*/
-#line 751 "./decision_rule.hweb"
+#line 745 "./decision_rule.hweb"
 
 class SimResultsDynamicStats:public SimResults{
 protected:
@@ -617,7 +611,7 @@ void calcVariance();
 #line 55 "./decision_rule.hweb"
 ;
 /*29:*/
-#line 775 "./decision_rule.hweb"
+#line 769 "./decision_rule.hweb"
 
 class SimulationIRFWorker;
 class SimResultsIRF:public SimResults{
@@ -646,7 +640,7 @@ void calcVariances();
 #line 56 "./decision_rule.hweb"
 ;
 /*30:*/
-#line 805 "./decision_rule.hweb"
+#line 799 "./decision_rule.hweb"
 
 class RTSimulationWorker;
 class RTSimResultsStats{
@@ -674,7 +668,7 @@ void writeMat4(FILE*fd,const char*lname);
 #line 57 "./decision_rule.hweb"
 ;
 /*31:*/
-#line 842 "./decision_rule.hweb"
+#line 836 "./decision_rule.hweb"
 
 class DynamicModel;
 class IRFResults{
@@ -693,7 +687,7 @@ void writeMat4(FILE*fd,const char*prefix)const;
 #line 58 "./decision_rule.hweb"
 ;
 /*32:*/
-#line 859 "./decision_rule.hweb"
+#line 853 "./decision_rule.hweb"
 
 class SimulationWorker:public THREAD{
 protected:
@@ -716,7 +710,7 @@ void operator()();
 #line 59 "./decision_rule.hweb"
 ;
 /*33:*/
-#line 882 "./decision_rule.hweb"
+#line 876 "./decision_rule.hweb"
 
 class SimulationIRFWorker:public THREAD{
 SimResultsIRF&res;
@@ -742,7 +736,7 @@ void operator()();
 #line 60 "./decision_rule.hweb"
 ;
 /*34:*/
-#line 909 "./decision_rule.hweb"
+#line 903 "./decision_rule.hweb"
 
 class RTSimulationWorker:public THREAD{
 protected:
@@ -765,7 +759,7 @@ void operator()();
 #line 61 "./decision_rule.hweb"
 ;
 /*35:*/
-#line 931 "./decision_rule.hweb"
+#line 925 "./decision_rule.hweb"
 
 class RandomShockRealization:virtual public ShockRealization{
 protected:
@@ -790,7 +784,7 @@ void schurFactor(const TwoDMatrix&v);
 #line 62 "./decision_rule.hweb"
 ;
 /*36:*/
-#line 954 "./decision_rule.hweb"
+#line 948 "./decision_rule.hweb"
 
 class ExplicitShockRealization:virtual public ShockRealization{
 TwoDMatrix shocks;
@@ -812,7 +806,7 @@ void print()const
 #line 63 "./decision_rule.hweb"
 ;
 /*37:*/
-#line 980 "./decision_rule.hweb"
+#line 974 "./decision_rule.hweb"
 
 class GenShockRealization:public RandomShockRealization,public ExplicitShockRealization{
 public:
