@@ -78,9 +78,7 @@
 /* Line 189 of yacc.c  */
 #line 1 "formula.y"
 
-/* Copyright 2006, Ondra Kamenik */
-
-/* $Id: formula.y 1749 2008-03-28 11:59:29Z kamenik $ */
+/* Copyright (C) 2006-2011, Ondra Kamenik */
 
 #include <cstdio>
 
@@ -88,19 +86,19 @@
 #include "formula_parser.h" 
 #include "formula_tab.hh"
 
-	int fmla_error(char*);
+	void fmla_error(const char*);
 	int fmla_lex(void);
 	extern int fmla_lineno;
 	extern ogp::FormulaParser* fparser;
 	extern YYLTYPE fmla_lloc;
 
-	static void print_token_value (FILE *, int, YYSTYPE);
-#define YYPRINT(file, type, value) print_token_value (file, type, value)
+  //  static void print_token_value (FILE *, int, YYSTYPE);
+  //  #define YYPRINT(file, type, value) print_token_value (file, type, value)
 
 
 
 /* Line 189 of yacc.c  */
-#line 104 "formula_tab.cc"
+#line 102 "formula_tab.cc"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -156,7 +154,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 23 "formula.y"
+#line 21 "formula.y"
 
 	char* string;
 	double dvalue;
@@ -165,7 +163,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 169 "formula_tab.cc"
+#line 167 "formula_tab.cc"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -190,7 +188,7 @@ typedef struct YYLTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 194 "formula_tab.cc"
+#line 192 "formula_tab.cc"
 
 #ifdef short
 # undef short
@@ -487,9 +485,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    44,    44,    45,    49,    49,    51,    53,    57,    58,
-      59,    60,    61,    62,    63,    64,    65,    66,    67,    68,
-      69,    70,    71,    72,    73,    74,    75
+       0,    42,    42,    43,    47,    47,    49,    51,    55,    56,
+      57,    58,    59,    60,    61,    62,    63,    64,    65,    66,
+      67,    68,    69,    70,    71,    72,    73
 };
 #endif
 
@@ -1477,161 +1475,161 @@ yyreduce:
         case 3:
 
 /* Line 1455 of yacc.c  */
-#line 46 "formula.y"
+#line 44 "formula.y"
     {fparser->add_formula((yyvsp[(1) - (1)].integer));;}
     break;
 
   case 6:
 
 /* Line 1455 of yacc.c  */
-#line 52 "formula.y"
+#line 50 "formula.y"
     {fparser->add_formula(fparser->add_binary(ogp::MINUS,(yyvsp[(1) - (4)].integer),(yyvsp[(3) - (4)].integer)));;}
     break;
 
   case 7:
 
 /* Line 1455 of yacc.c  */
-#line 54 "formula.y"
+#line 52 "formula.y"
     {fparser->add_formula((yyvsp[(1) - (2)].integer));;}
     break;
 
   case 8:
 
 /* Line 1455 of yacc.c  */
-#line 57 "formula.y"
+#line 55 "formula.y"
     { (yyval.integer) = (yyvsp[(2) - (3)].integer);;}
     break;
 
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 58 "formula.y"
+#line 56 "formula.y"
     {(yyval.integer)=fparser->add_binary(ogp::PLUS,(yyvsp[(1) - (3)].integer),(yyvsp[(3) - (3)].integer));;}
     break;
 
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 59 "formula.y"
+#line 57 "formula.y"
     {(yyval.integer)=fparser->add_binary(ogp::MINUS,(yyvsp[(1) - (3)].integer),(yyvsp[(3) - (3)].integer));;}
     break;
 
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 60 "formula.y"
+#line 58 "formula.y"
     {(yyval.integer)=fparser->add_binary(ogp::TIMES,(yyvsp[(1) - (3)].integer),(yyvsp[(3) - (3)].integer));;}
     break;
 
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 61 "formula.y"
+#line 59 "formula.y"
     {(yyval.integer)=fparser->add_binary(ogp::DIVIDE,(yyvsp[(1) - (3)].integer),(yyvsp[(3) - (3)].integer));;}
     break;
 
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 62 "formula.y"
+#line 60 "formula.y"
     {(yyval.integer)=fparser->add_binary(ogp::POWER,(yyvsp[(1) - (3)].integer),(yyvsp[(3) - (3)].integer));;}
     break;
 
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 63 "formula.y"
+#line 61 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::UMINUS,(yyvsp[(2) - (2)].integer));;}
     break;
 
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 64 "formula.y"
+#line 62 "formula.y"
     {(yyval.integer) = (yyvsp[(2) - (2)].integer);;}
     break;
 
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 65 "formula.y"
+#line 63 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::SIN,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 66 "formula.y"
+#line 64 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::COS,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 67 "formula.y"
+#line 65 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::TAN,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 68 "formula.y"
+#line 66 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::EXP,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 20:
 
 /* Line 1455 of yacc.c  */
-#line 69 "formula.y"
+#line 67 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::LOG,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 70 "formula.y"
+#line 68 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::SQRT,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 71 "formula.y"
+#line 69 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::ERF,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 72 "formula.y"
+#line 70 "formula.y"
     {(yyval.integer)=fparser->add_unary(ogp::ERFC,(yyvsp[(3) - (4)].integer));;}
     break;
 
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 73 "formula.y"
+#line 71 "formula.y"
     {(yyval.integer)=fparser->add_derivative((yyvsp[(3) - (6)].integer), fparser->add_nulary((yyvsp[(5) - (6)].string)));;}
     break;
 
   case 25:
 
 /* Line 1455 of yacc.c  */
-#line 74 "formula.y"
+#line 72 "formula.y"
     {(yyval.integer)=fparser->add_nulary((yyvsp[(1) - (1)].string));;}
     break;
 
   case 26:
 
 /* Line 1455 of yacc.c  */
-#line 75 "formula.y"
+#line 73 "formula.y"
     {(yyval.integer)=fparser->add_nulary((yyvsp[(1) - (1)].string));;}
     break;
 
 
 
 /* Line 1455 of yacc.c  */
-#line 1635 "formula_tab.cc"
+#line 1633 "formula_tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1850,17 +1848,19 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 78 "formula.y"
+#line 76 "formula.y"
 
 
-int fmla_error(char* s)
+void fmla_error(const char* s)
 {
 	fparser->error(s);
 }
 
+/*
 static void print_token_value(FILE* file, int type, YYSTYPE value)
 {
 	if (type == NAME)
 		fprintf(file, "%s", value.string);
 }
+*/
 
