@@ -76,13 +76,13 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 1 "namelist.y"
+#line 3 "namelist.y"
 
 #include "location.h"
 #include "namelist.h"
 #include "namelist_tab.hh"
 
-	int namelist_error(char*);
+	void namelist_error(const char*);
 	int namelist_lex(void);
 	extern ogp::NameListParser* name_list_parser;
 
@@ -129,7 +129,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 12 "namelist.y"
+#line 14 "namelist.y"
 
 	int integer;
 	char *string;
@@ -448,7 +448,7 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    28,    28,    29,    30
+       0,    30,    30,    31,    32
 };
 #endif
 
@@ -1379,21 +1379,21 @@ yyreduce:
         case 2:
 
 /* Line 1455 of yacc.c  */
-#line 28 "namelist.y"
+#line 30 "namelist.y"
     {name_list_parser->add_name((yyvsp[(2) - (2)].string));;}
     break;
 
   case 3:
 
 /* Line 1455 of yacc.c  */
-#line 29 "namelist.y"
+#line 31 "namelist.y"
     {name_list_parser->add_name((yyvsp[(3) - (3)].string));;}
     break;
 
   case 4:
 
 /* Line 1455 of yacc.c  */
-#line 30 "namelist.y"
+#line 32 "namelist.y"
     {name_list_parser->add_name((yyvsp[(1) - (1)].string));;}
     break;
 
@@ -1619,10 +1619,10 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 33 "namelist.y"
+#line 35 "namelist.y"
 
 
-int namelist_error(char* mes)
+void namelist_error(const char* mes)
 {
 	name_list_parser->namelist_error(mes);
 }
