@@ -1,8 +1,8 @@
-function [r, g1] = block_mfs_steadystate(y, b)
+function [r, g1] = block_mfs_steadystate(y, b, y_all)
 % Wrapper around the *_static.m file, for use with dynare_solve,
 % when block_mfs option is given to steady.
 
-% Copyright (C) 2009 Dynare Team
+% Copyright (C) 2009-2010 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -21,10 +21,10 @@ function [r, g1] = block_mfs_steadystate(y, b)
 
 global M_ oo_
 
-ss = oo_.steady_state;
 indx = M_.blocksMFS{b};
 
-ss(indx) = y;
+y_all(indx) = y;
 x = [oo_.exo_steady_state; oo_.exo_det_steady_state];
 
-eval(['[r,g1] = ' M_.fname '_static(b, ss, x, M_.params);']);
+eval(['[r,g1] = ' M_.fname '_static(b, y_all, x, M_.params);']);
+g1 = full(g1);
\ No newline at end of file
