@@ -52,7 +52,7 @@ if ~exist('OCTAVE_VERSION')
     addpath([dynareroot '/missing/rows_columns'])
     % Replacement for vec() (inexistent under MATLAB)
     addpath([dynareroot '/missing/vec'])
-    if ~license('test', 'statistics_toolbox')
+    if isempty(license('inuse','statistics_toolbox'))
         % Replacements for functions of the stats toolbox
         addpath([dynareroot '/missing/stats/'])
     end
@@ -119,6 +119,27 @@ else
         end
     end
 
+    if strcmp(computer, 'MACI')
+        if matlab_ver_less_than('7.5')
+            mexpath = [dynareroot '../mex/matlab/osx32-7.4'];
+            if exist(mexpath, 'dir')
+                addpath(mexpath)
+            end
+        else
+            mexpath = [dynareroot '../mex/matlab/osx32-7.5-7.13'];
+            if exist(mexpath, 'dir')
+                addpath(mexpath)
+            end
+        end
+    end
+
+    if strcmp(computer, 'MACI64')
+        mexpath = [dynareroot '../mex/matlab/osx64'];
+        if exist(mexpath, 'dir')
+            addpath(mexpath)
+        end
+    end
+
     % Add generic MATLAB path (with higher priority than the previous ones)
     addpath([dynareroot '../mex/matlab/']);
 end
