@@ -61,17 +61,16 @@ for i = 1:size(M_.endo_names,1)
 end
 
 %% Set the order of approximation to one (if needed).
-if options_.order > 1
-    if ~exist('particle','dir')
-        disp('This version of Dynare cannot estimate non linearized models!')
-        disp('Set "order" equal to 1.')
-        disp(' ')
-        options_.order = 1;
-    end
+if options_.order > 1 && ~isfield(options_,'nonlinear_filter')
+    disp('This version of Dynare cannot estimate non linearized models!')
+    disp('Set "order" equal to 1.')
+    disp(' ')
+    options_.order = 1;
 end
 
-%% Set options_.lik_init equal to 3 if diffuse filter is used.
-if (options_.diffuse_filter==1) && (options_.lik_init==1)
+% Set options_.lik_init equal to 3 if diffuse filter is used or
+% kalman_algo refers to a diffuse filter algorithm.
+if (options_.diffuse_filter==1) || (options_.kalman_algo > 2)
     options_.lik_init = 3;
 end
 
@@ -125,7 +124,7 @@ if ~isempty(estim_params_)
     [xparam1,estim_params_,bayestopt_,lb,ub,M_] = set_prior(estim_params_,M_,options_);
     if any(bayestopt_.pshape > 0)
         % Plot prior densities.
-        if options_.plot_priors
+        if ~options_.nograph && options_.plot_priors
             plot_priors(bayestopt_,M_,options_)
         end
         % Set prior bounds
