@@ -71,10 +71,9 @@ while i<n,
         end
         xh1=x;
     end
-    save gstep.mat
+    save gstep.mat x h1 f0
 end
 
-save gstep.mat
-
+save gstep.mat x h1 f0
 
 
