@@ -6,7 +6,7 @@ function [hessian_mat, gg, htol1, ihh, hh_mat0, hh1] = mr_hessian(init,x,func,hf
 %
 % adapted from Michel Juillard original rutine hessian.m
 %
-%  func =  name of the function: func must give two outputs: 
+%  func =  function handle. The function must give two outputs:
 %    - the log-likelihood AND the single contributions at times t=1,...,T
 %    of the log-likelihood to compute outer product gradient
 %  x = parameter values
@@ -148,7 +148,6 @@ while i<n,
         h1(i)=h10;
         i=0;
     end
-    save hess.mat
 end
 
 h_1=h1;
@@ -182,7 +181,6 @@ if hflag==2,
             xh_1(i)=x(i);
             xh_1(j)=x(j);
             j=j+1;
-            save hess.mat
         end
         i=i+1;
     end
@@ -206,7 +204,7 @@ hh_mat0=ggh'*ggh;  % outer product hessian
 A=diag(2.*h1);  % rescaling matrix
 % igg=inv(hh_mat);  % inverted rescaled outer product hessian
 ihh=A'*(hh_mat\A);  % inverted outer product hessian
-if hflag>0 & min(eig(reshape(hessian_mat,n,n)))>0,
+if hflag>0 && min(eig(reshape(hessian_mat,n,n)))>0,
     hh0 = A*reshape(hessian_mat,n,n)*A';  %rescaled second order derivatives
     hh = reshape(hessian_mat,n,n);  %rescaled second order derivatives
     sd0=sqrt(diag(hh0));   %rescaled 'standard errors' using second order derivatives
@@ -244,7 +242,4 @@ if any(isnan(hessian_mat)),
 end
 hh1=h1;
 htol1=htol;
-save hess.mat
-% 11/25/03 SA Created from Hessian_sparse (removed sparse)
-
-
+save hess.mat hessian_mat
