@@ -17,18 +17,11 @@
  * along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "k_ord_dynare.hh"
 #include "dynamic_dll.hh"
 
 #include <sstream>
 
-/***********************************
- * Members of DynamicModelDLL for handling loading and calling
- * <model>_dynamic () function
- **************************************/
-DynamicModelDLL::DynamicModelDLL(const string &modName, const int y_length, const int j_cols,
-                                 const int n_max_lag, const int n_exog, const Vector &ySteady_arg, const string &sExt) throw (DynareException) :
-  length(y_length), jcols(j_cols), nMax_lag(n_max_lag), nExog(n_exog), ySteady(ySteady_arg)
+DynamicModelDLL::DynamicModelDLL(const string &modName, const string &sExt) throw (DynareException)
 {
   string fName;
 #if !defined(__CYGWIN32__) && !defined(_WIN32)
@@ -42,7 +35,7 @@ DynamicModelDLL::DynamicModelDLL(const string &modName, const int y_length, cons
       dynamicHinstance = LoadLibrary(fName.c_str());
       if (dynamicHinstance == NULL)
         throw 1;
-      Dynamic = (DynamicFn) GetProcAddress(dynamicHinstance, "Dynamic");
+      Dynamic = (DynamicDLLFn) GetProcAddress(dynamicHinstance, "Dynamic");
       if (Dynamic == NULL)
         {
           FreeLibrary(dynamicHinstance); // Free the library
@@ -55,7 +48,7 @@ DynamicModelDLL::DynamicModelDLL(const string &modName, const int y_length, cons
           cerr << dlerror() << endl;
           throw 1;
         }
-      Dynamic = (DynamicFn) dlsym(dynamicHinstance, "Dynamic");
+      Dynamic = (DynamicDLLFn) dlsym(dynamicHinstance, "Dynamic");
       if ((Dynamic  == NULL) || dlerror())
         {
           dlclose(dynamicHinstance); // Free the library
@@ -94,30 +87,9 @@ DynamicModelDLL::~DynamicModelDLL()
 }
 
 void
-DynamicModelDLL::eval(const Vector &y, const Vector &x, const Vector *modParams,
+DynamicModelDLL::eval(const Vector &y, const Vector &x, const Vector &modParams, const Vector &ySteady,
                       Vector &residual, TwoDMatrix *g1, TwoDMatrix *g2, TwoDMatrix *g3) throw (DynareException)
 {
-  double  *dresidual, *dg1 = NULL, *dg2 = NULL, *dg3 = NULL;
-
-  if ((jcols-nExog) != y.length())
-    throw DynareException(__FILE__, __LINE__, "DLL Error: (jcols-nExog)!=ys.length()");
-
-  if (g1 != NULL)
-    {
-      if (g1->nrows() != length)
-        throw DynareException(__FILE__, __LINE__, "DLL Error: g1 has wrong size");
-      dg1 = const_cast<double *>(g1->base());
-    }
-  if (g2 != NULL)
-    dg2 = const_cast<double *>(g2->base());
-  dresidual = const_cast<double *>(residual.base());
-  if (g3 != NULL)
-    dg3 = const_cast<double *>(g3->base());
-  dresidual = const_cast<double *>(residual.base());
-  double *dy = const_cast<double *>(y.base());
-  double *dx = const_cast<double *>(x.base());
-  double *dbParams = const_cast<double *>(modParams->base());
-  double *steady_state = const_cast<double *>(ySteady.base());
-
-  Dynamic(dy, dx, 1, dbParams, steady_state, 0, dresidual, dg1, dg2, dg3);
+  Dynamic(y.base(), x.base(), 1, modParams.base(), ySteady.base(), 0, residual.base(), g1->base(),
+          g2 == NULL ? NULL : g2->base(), g3 == NULL ? NULL : g3->base());
 }
