@@ -140,7 +140,12 @@ ModFile::checkPass()
       cerr << "ERROR: In 'model' block, 'use_dll' option is not compatible with 'block' or 'bytecode'" << endl;
       exit(EXIT_FAILURE);
     }
-
+  if (block || byte_code)
+    if (dynamic_model.isModelLocalVariableUsed())
+      {
+        cerr << "ERROR: In 'model' block, 'block' or 'bytecode' options are not yet compatible with pound expressions" << endl;
+        exit(EXIT_FAILURE);
+      }
   if ((stochastic_statement_present || mod_file_struct.check_present || mod_file_struct.steady_present) && no_static)
     {
       cerr << "ERROR: no_static option is incompatible with stoch_simul, estimation, osr, ramsey_policy, steady and check commands" << endl;
@@ -379,7 +384,11 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all, bool console,
               << "%           from model file (.mod)" << endl << endl;
 
   if (clear_all)
-    mOutputFile << "clear all" << endl;
+    {
+      mOutputFile << "clear all" << endl
+	// this is a work-around for a bug in Octave 3.2
+		  << "clear global" << endl;
+    }
 
   mOutputFile << "tic;" << endl
               << "global M_ oo_ options_ ys0_ ex0_" << endl
@@ -441,6 +450,22 @@ ModFile::writeOutputFiles(const string &basename, bool clear_all, bool console,
   if (!use_dll)
     mOutputFile << "erase_compiled_function('" + basename + "_dynamic');" << endl;
 
+  // Erase generated steady state file (see ticket #224)
+  string steadystatefile = basename + "_steadystate.m";
+  ifstream in(steadystatefile.c_str(), ios::binary);
+  if (!in.fail())
+    {
+      string line;
+      getline(in, line);
+      if (!line.compare(STEADY_STATE_GENERATED_HEADER))
+        {
+          in.close();
+          unlink(steadystatefile.c_str());
+        }
+      else
+        in.close();
+    }
+  
 #if defined(_WIN32) || defined(__CYGWIN32__)
   // If using USE_DLL with MSVC, check that the user didn't use a function not supported by MSVC (because MSVC doesn't comply with C99 standard)
   if (use_dll && msvc)
