@@ -408,7 +408,6 @@ StaticModel::writeModelEquationsOrdered_M(const string &static_basename) const
           break;
         }
       output << "end" << endl;
-      writePowerDeriv(output, false);
       output.close();
     }
 }
@@ -576,7 +575,6 @@ StaticModel::writeModelEquationsCode(const string file_name, const string bin_ba
   fendblock.write(code_file, instruction_number);
   FEND_ fend;
   fend.write(code_file, instruction_number);
-  writePowerDeriv(code_file, false);
   code_file.close();
 }
 
@@ -1188,7 +1186,7 @@ StaticModel::writeStaticMFile(const string &func_name) const
       expr_t d1 = it->second;
 
       output << "  g1(" << eq+1 << "," << symbol_table.getTypeSpecificID(symb_id)+1 << ")=";
-      d1->writeOutput(output, oMatlabStaticModel, temporary_terms);
+      d1->writeOutput(output, oMatlabStaticModel, temporary_terms, tef_terms);
       output << ";" << endl;
     }
 
@@ -1226,7 +1224,7 @@ StaticModel::writeStaticMFile(const string &func_name) const
           output << "v2(" << k+1 << ",1)=" << eq + 1 << ";" << endl
                  << "v2(" << k+1 << ",2)=" << col_nb + 1 << ";" << endl
                  << "v2(" << k+1 << ",3)=";
-          d2->writeOutput(output, oMatlabStaticModel, temporary_terms);
+          d2->writeOutput(output, oMatlabStaticModel, temporary_terms, tef_terms);
           output << ";" << endl;
 
           k++;
@@ -1248,7 +1246,6 @@ StaticModel::writeStaticMFile(const string &func_name) const
 
   output << "end" << endl; // Close the if nargout >= 3 statement
   output << "end" << endl; // Close the *_static function
-  writePowerDeriv(output, false);
   output.close();
 }
 
@@ -1332,7 +1329,6 @@ StaticModel::writeStaticBlockMFSFile(const string &basename) const
     }
   output << "  end" << endl
          << "end" << endl;
-  writePowerDeriv(output, false);
   output.close();
 }
 
